# -*- coding: utf-8 -*-
from django.core.urlresolvers import reverse

from formfieldstash.tests.utils.django_utils import create_superuser
from formfieldstash.tests.utils.selenium_utils import SeleniumTestCase, CustomWebDriver
from formfieldstash.tests.test_app.models import TestModelSingle, TestModelAdvanced


class FormFieldStashAdminTests(SeleniumTestCase):
    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_app_index_get(self):
        self.login()
        self.open(reverse('admin:index'))



# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2017-07-04 15:20
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='TestInlineModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('field1', models.CharField(blank=True, default='', max_length=64)),
                ('field2', models.CharField(blank=True, default='', max_length=64)),
            ],
        ),
        migrations.CreateModel(
            name='TestModel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('field0', models.CharField(blank=True, default='', max_length=64)),
                ('field1', models.CharField(blank=True, default='', max_length=64)),
                ('field2', models.CharField(blank=True, default='', max_length=64)),
            ],
        ),
        migrations.AddField(
            model_name='testinlinemodel',
            name='testmodel',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='test_app.TestModel'),
        ),
    ]



# coding: utf-8
from __future__ import unicode_literals

from django import template


register = template.Library()


@register.inclusion_tag('djangocms_misc/tags/page_link.html', takes_context=True)
def djangocms_misc_page_link(context, lookup, css_class='', link_text=''):
    context.update({'lookup': lookup, 'css_class': css_class, 'link_text': link_text, })
    return context



from __future__ import unicode_literals

from django.db import models
from django.utils.encoding import python_2_unicode_compatible


@python_2_unicode_compatible
class TestModel(models.Model):
    field0 = models.CharField(max_length=64, default='', blank=True)
    field1 = models.CharField(max_length=64, default='', blank=True)
    field2 = models.CharField(max_length=64, default='', blank=True)

    def __str__(self):
        return self.field1


@python_2_unicode_compatible
class TestInlineModel(models.Model):
    testmodel = models.ForeignKey(TestModel)
    field1 = models.CharField(max_length=64, default='', blank=True)
    field2 = models.CharField(max_length=64, default='', blank=True)

    def __str__(self):
        return self.field1
